(* d_kp2dpo.m *)
(* Menu item 2-4 *)

(* Last Updated:  1 September, 2008, 18:03 by DP at CSM *)

(***  POTENTIAL KADOMTSEV-PETVIASHVILI (PKP) EQUATION  ***)

(* The potential form of the KP used by Infeld and Frycz requires       *)
(* alpha = 1;                                                           *)

eq[1] = D[u[1][x,y,t],t,x] + alpha*D[u[1][x,y,t],x]*D[u[1][x,y,t],{x,2}] +
        D[u[1][x,y,t],{x,4}] + sigma^2*D[u[1][x,y,t],{y,2}];

(* NOTE:  To put the PKP equation in evolution form, y and t must be    *)
(* interchanged. Then an auxillary dependent variable is be introduced, *)
(* forming a system. The evolution system for the PKP equation is       *)
(*
eq[1] = D[u[1][x,y,t],t] - u[2][x,y,t];

eq[2] = D[u[2][x,y,t],t] + (1/sigma^2)*(D[u[1][x,y,t],x,y] +
        alpha*D[u[1][x,y,t],x]*D[u[1][x,y,t],{x,2}] +
        D[u[1][x,y,t],{x,4}]);
*)

diffFunctionListINPUT = {eq[1]};
numDependentVariablesINPUT = 1;
independentVariableListINPUT = {x,y};
nameINPUT = "potential Kadomtsev-Petviashvili Equation";
(* noteINPUT = "To create evolution equations with respect to the t-variable, "<>
            "the variables y and t have been switched with each other in the "<>
            "equations given to the program."  <>
            "\n\n Equation is in the form given in Infeld and Frycz." *)

parametersINPUT = {alpha,sigma};
weightedParametersINPUT = {};

userWeightRulesINPUT = {};
rankRhoINPUT = Null;
explicitIndependentVariablesInDensitiesINPUT = Null;

(* formRhoINPUT only works with the evolution system.  The conservation *)
(* laws being tested must be transformed to match the evolution system. *)
formRhoINPUT = {}; (*D[u[1][x,y,t],x]*D[u[1][x,y,t],y] *)

(* Generalized densities with explicit independent variables.           *)
(* To test these densities, use the evolution form of the KP equation.  *)
(*
Clear[n];
formRhoINPUT = y^(n-1)*(y*D[u[1][x,y,t],x] - x)*u[2][x,y,t] +
               y^(n-2)*t*(t*u[2][x,y,t] - u[1][x,y,t]);
*)
(*
Clear[n];
formRhoINPUT = y^n*(D[u[1][x,y,t],x]*D[u[1][x,y,t],y] + D[u[1][x,y,t],x]^3 +
               D[u[1][x,y,t],{x,2}]^2 + u[2][x,y,t]^2) +
               t*y^(n-2)*(y*D[u[1][x,y,t],x] + x)*u[2][x,y,t] +
               t^2*y^(n-3)*(t*u[2][x,y,t] - u[1][x,y,t]) + x*y^(n-2)*u[1][x,y,t];
*)
(*
Clear[n];
formRhoINPUT = y^n*D[u[1][x,y,t],y]*u[2][x,y,t] +
               y^(n-2)*(y*x - t^2)*D[u[1][x,y,t],x]*u[2][x,y,t] +
               y^(n-1)*t*(D[u[1][x,y,t],x]^3 +
               D[u[1][x,y,t],y]*D[u[1][x,y,t],x] +
               D[u[1][x,y,t],{x,2}]^2 + u[2][x,y,t]^2) +
               y^(n-1)*u[1][x,y,t]*u[2][x,y,t] +
               y^(n-3)*x*(y*x - t^2)*u[2][x,y,t] +
               y^(n-3)*x*t*u[1][x,y,t] +
               y^(n-4)*t^3*u[1][x,y,t] + y^(n-4)*t^4*u[2][x,y,t];
*)
(* Generalized densities with y^n replaced by f[y].                     *)
(*
Clear[ff];
formRhoINPUT = (-t)*D[ff[y],{y,2}]*u[1][x,y,t] +
               t^2*D[ff[y],{y, 2}]*u[2][x,y,t] -
               x*D[ff[y],y]*u[2][x,y,t] +
               ff[y]*u[2][x,y,t]*D[u[1][x,y,t],x];
*)
(*
Clear[gg];
formRhoINPUT = (-t^2)*D[gg[y],{y,3}]*u[1][x,y,t] +
               x*D[gg[y],{y,2}]*u[1][x,y,t] + t^3*D[gg[y],{y,3}]*u[2][x,y,t] +
               t*x*D[gg[y],{y,2}]*u[2][x,y,t] + gg[y]*u[2][x,y,t]^2 +
               t*D[gg[y],y]*u[2][x,y,t]*D[u[1][x,y,t],x] +
               gg[y]*D[u[1][x,y,t],y]*D[u[1][x,y,t],x] +
               gg[y]*D[u[1][x,y,t],x]^3 +
               gg[y]*D[u[1][x,y,t],{x,2}]^2;
*)
(*
formRhoINPUT = hh[y]*D[u[1][x,y,t],y]*u[2][x,y,t] +
               D[hh[y],{y,1}]*x*D[u[1][x,y,t],x]*u[2][x,y,t] +
               D[hh[y],{y,2}]*t^2*D[u[1][x,y,t],x]*u[2][x,y,t] +
               D[hh[y],y]*t*(D[u[1][x,y,t],x]^3 +
               D[u[1][x,y,t],y]*D[u[1][x,y,t],x] + D[u[1][x,y,t],{x,2}]^2 +
               u[2][x,y,t]^2) + D[hh[y], y]*u[1][x,y,t]*u[2][x,y,t] +
               D[hh[y],{y,2}]*x^2*u[2][x,y,t] +
               D[hh[y],{y,3}]*x*t^2*u[2][x,y,t] +
               D[hh[y],{y,3}]*x*t*u[1][x,y,t] +
               D[hh[y],{y,4}]*t^3*u[1][x,y,t] +
               D[hh[y],{y,4}]*t^4*u[2][x,y,t];
*)

(* REFERENCE:                                                           *)
(* E. Infeld and P. Frycz, Infinite Sequences of conservation laws for  *)
(* the Kadomtsev-Petviashvili equation,                                 *)
(* Acta Phys. Polon., V. B14 (1984), pp. 129-132.                       *)

(* d_kp2dpo.m *)
(* end of file *)
